package App::rmspaces;

use strict;
use warnings;

our $VERSION = 0.6;

1;

__END__

=head1 NAME

App::rmspaces - an app to remove spaces from file names

=head1 DESCRIPTION

This is a stub module, see F<script/rmspaces> for details of the app.

=head1 AUTHOR

Athos Ribeiro

=head1 LICENSE AND COPYRIGHT

Copyright 2017 Athos Ribeiro <athoscr@fedoraproject.org>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

=cut

